import { Emitter } from 'vscode/vscode/vs/base/common/event';
import { IActionViewItem } from 'vscode/vscode/vs/base/browser/ui/actionbar/actionbar';
import { IAction } from 'vscode/vscode/vs/base/common/actions';
import { Part, IPartOptions } from 'vscode/vscode/vs/workbench/browser/part';
import { Composite, CompositeRegistry } from 'vscode/vscode/vs/workbench/browser/composite';
import { IComposite } from 'vscode/vscode/vs/workbench/common/composite';
import { IWorkbenchLayoutService } from 'vscode/vscode/vs/workbench/services/layout/browser/layoutService';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IContextMenuService } from 'vscode/vscode/vs/platform/contextview/browser/contextView';
import { IInstantiationService } from 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import { IProgressIndicator } from 'vscode/vscode/vs/platform/progress/common/progress';
import { IKeybindingService } from 'vscode/vscode/vs/platform/keybinding/common/keybinding';
import { IThemeService } from 'vscode/vscode/vs/platform/theme/common/themeService';
import { INotificationService } from 'vscode/vscode/vs/platform/notification/common/notification';
import { AnchorAlignment } from 'vscode/vscode/vs/base/browser/ui/contextview/contextview';
import { WorkbenchToolBar } from '../../../platform/actions/browser/toolbar.js';
import { IBoundarySashes } from 'vscode/vscode/vs/base/browser/ui/sash/sash';
import { IBaseActionViewItemOptions } from 'vscode/vscode/vs/base/browser/ui/actionbar/actionViewItems';
import { IHoverDelegate } from 'vscode/vscode/vs/base/browser/ui/iconLabel/iconHoverDelegate';

interface ICompositeTitleLabel {
    /**
     * Asks to update the title for the composite with the given ID.
     */
    updateTitle(id: string, title: string, keybinding?: string): void;
    /**
     * Called when theming information changes.
     */
    updateStyles(): void;
}
declare abstract class CompositePart<T extends Composite> extends Part {
    private readonly notificationService;
    protected readonly storageService: IStorageService;
    protected readonly contextMenuService: IContextMenuService;
    protected readonly keybindingService: IKeybindingService;
    protected readonly instantiationService: IInstantiationService;
    protected readonly registry: CompositeRegistry<T>;
    private readonly activeCompositeSettingsKey;
    private readonly defaultCompositeId;
    private readonly nameForTelemetry;
    private readonly compositeCSSClass;
    private readonly titleForegroundColor;
    protected readonly onDidCompositeOpen: Emitter<{
        composite: IComposite;
        focus: boolean;
    }>;
    protected readonly onDidCompositeClose: Emitter<IComposite>;
    protected toolBar: WorkbenchToolBar | undefined;
    protected titleLabelElement: HTMLElement | undefined;
    protected readonly hoverDelegate: IHoverDelegate;
    private readonly mapCompositeToCompositeContainer;
    private readonly mapActionsBindingToComposite;
    private activeComposite;
    private lastActiveCompositeId;
    private readonly instantiatedCompositeItems;
    private titleLabel;
    private progressBar;
    private contentAreaSize;
    private readonly actionsListener;
    private currentCompositeOpenToken;
    private boundarySashes;
    constructor(notificationService: INotificationService, storageService: IStorageService, contextMenuService: IContextMenuService, layoutService: IWorkbenchLayoutService, keybindingService: IKeybindingService, instantiationService: IInstantiationService, themeService: IThemeService, registry: CompositeRegistry<T>, activeCompositeSettingsKey: string, defaultCompositeId: string, nameForTelemetry: string, compositeCSSClass: string, titleForegroundColor: string | undefined, id: string, options: IPartOptions);
    protected openComposite(id: string, focus?: boolean): Composite | undefined;
    private doOpenComposite;
    protected createComposite(id: string, isActive?: boolean): Composite;
    protected showComposite(composite: Composite): void;
    protected onTitleAreaUpdate(compositeId: string): void;
    private updateTitle;
    private collectCompositeActions;
    protected getActiveComposite(): IComposite | undefined;
    protected getLastActiveCompositeId(): string;
    protected hideActiveComposite(): Composite | undefined;
    protected createTitleArea(parent: HTMLElement): HTMLElement;
    protected createTitleLabel(parent: HTMLElement): ICompositeTitleLabel;
    updateStyles(): void;
    protected actionViewItemProvider(action: IAction, options: IBaseActionViewItemOptions): IActionViewItem | undefined;
    protected actionsContextProvider(): unknown;
    protected createContentArea(parent: HTMLElement): HTMLElement;
    getProgressIndicator(id: string): IProgressIndicator | undefined;
    protected getTitleAreaDropDownAnchorAlignment(): AnchorAlignment;
    layout(width: number, height: number, top: number, left: number): void;
    setBoundarySashes?(sashes: IBoundarySashes): void;
    protected removeComposite(compositeId: string): boolean;
    dispose(): void;
}

export { CompositePart, type ICompositeTitleLabel };
